package VMOMI::HostIncompatibleForFaultToleranceReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
